@@ -40,7 +40,6 @@ class ESImporter:
         for item in generator:
             yield {
                 "_index": index_name,
-                "_type": index_name,
                 "_source": item
             }
 
@@ -100,7 +99,6 @@ class ESImporter:
 
                 yield {
                     "_index": mails_index,
-                    "_type": mails_index,
                     "_source": mail
                 }
 
@@ -112,7 +110,6 @@ class ESImporter:
                     self._try_add_file_url(attachment, toolkit_url, tk_media_folder)
                     yield {
                         "_index": attachments_index,
-                        "_type": attachments_index,
                         "_source": attachment
                     }
             else:
@@ -123,7 +120,6 @@ class ESImporter:
 
                 yield {
                     "_index": index_name,
-                    "_type": index_name,
                     "_source": item
                 }
 
@@ -131,7 +127,7 @@ class ESImporter:
     def _add_texta_facts_mapping(self, index):
         self.es.indices.create(index, ignore=[400, 404])
 
-        m = Mapping(index)
+        m = Mapping()
         texta_facts = Nested(
             properties={
                 "spans": Keyword(),
